//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
#property indicator_separate_window
#property indicator_buffers 2
#property indicator_color1  ForestGreen
#property indicator_color2  Red
#property indicator_width1  2
#property indicator_width2  2
#property indicator_minimum 0
#property indicator_maximum 1

extern string TimeFrame       = "Current time frame";
extern int    period          = 1;
extern bool   alertsOn        = true;
extern bool   alertsOnCurrent = true;
extern bool   alertsMessage   = true;
extern bool   alertsSound     = false;
extern bool   alertsNotify    = true;
extern bool   alertsEmail     = true;
extern string soundFile       = "alert2.wav"; 

double Up[];
double Down[];
double Pr[];

string indicatorFileName;
bool   returnBars;
int    timeFrame;


//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

int init(){
   IndicatorBuffers(3);
   SetIndexBuffer(0,Up);   SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexBuffer(1,Down); SetIndexStyle(1,DRAW_HISTOGRAM);
   SetIndexBuffer(2,Pr);

      //
      //
      //
      //
      //
      
      indicatorFileName = WindowExpertName();
      returnBars        = TimeFrame == "returnBars";     if (returnBars)     return(0);
      timeFrame         = stringToTimeFrame(TimeFrame);

      //
      //
      //
      //
      //
      
      IndicatorShortName(timeFrameToString(timeFrame)+" TSV");   
   return(0);
}
int start()
{
   int counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
         if (returnBars) { Up[0] = limit+1; return(0); }
         if (timeFrame!=Period())  limit = MathMax(limit,MathMin(Bars-1,iCustom(NULL,timeFrame,indicatorFileName,"returnBars",0,0)*timeFrame/Period()));

   //
   //
   //
   //
   //
   //

   for(int i=limit; i >= 0; i--)
   {
      int y = iBarShift(NULL,timeFrame,Time[i]);
      double val =iMA(NULL,timeFrame,period,1,MODE_SMA,PRICE_HIGH,y);
      double val2=iMA(NULL,timeFrame,period,1,MODE_SMA,PRICE_LOW ,y);
            Pr[i]   = Pr[i+1];
            Up[i]   = EMPTY_VALUE;
            Down[i] = EMPTY_VALUE;
            if (iClose(NULL,timeFrame,y)<val2) Pr[i] = -1;
            if (iClose(NULL,timeFrame,y)>val ) Pr[i] =  1;
               if (Pr[i]== 1) Up[i]   = 1; 
               if (Pr[i]==-1) Down[i] = 1;
   } 
   manageAlerts();
   return(0);
}

//+-------------------------------------------------------------------
//|                                                                  
//+-------------------------------------------------------------------
//
//
//
//
//

string sTfTable[] = {"M1","M5","M15","M30","H1","H4","D1","W1","MN"};
int    iTfTable[] = {1,5,15,30,60,240,1440,10080,43200};

//
//
//
//
//

int stringToTimeFrame(string tfs)
{
   tfs = stringUpperCase(tfs);
   for (int i=ArraySize(iTfTable)-1; i>=0; i--)
         if (tfs==sTfTable[i] || tfs==""+iTfTable[i]) return(MathMax(iTfTable[i],Period()));
                                                      return(Period());
}

//
//
//
//
//

string timeFrameToString(int tf)
{
   for (int i=ArraySize(iTfTable)-1; i>=0; i--) 
         if (tf==iTfTable[i]) return(sTfTable[i]);
                              return("");
}

//
//
//
//
//

string stringUpperCase(string str)
{
   string   s = str;

   for (int length=StringLen(str)-1; length>=0; length--)
   {
      int char = StringGetChar(s, length);
         if((char > 96 && char < 123) || (char > 223 && char < 256))
                     s = StringSetChar(s, length, char - 32);
         else if(char > -33 && char < 0)
                     s = StringSetChar(s, length, char + 224);
   }
   return(s);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
//
//
//
//
//

void manageAlerts()
{
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1; whichBar = iBarShift(NULL,0,iTime(NULL,timeFrame,whichBar));
      if (Pr[whichBar] != Pr[whichBar+1])
      {
         if (Pr[whichBar] == 1) doAlert(whichBar,"up");
         if (Pr[whichBar] ==-1) doAlert(whichBar,"down");
      }         
   }
}   

//
//
//
//
//

void doAlert(int forBar, string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[forBar]) {
          previousAlert  = doWhat;
          previousTime   = Time[forBar];

          //
          //
          //
          //
          //

           message =  StringConcatenate(Symbol()," ",timeFrameToString(timeFrame)," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," T.S.V. Bullish & Bearish ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," T.S.V. Bullish & Bearish " +" "+message));
             if (alertsEmail)   SendMail(StringConcatenate(Symbol(), Period(), " T.S.V. Bullish & Bearish "),message);
             if (alertsSound)   PlaySound(soundFile);
      }
}